        within SpatialPlotExamples;

model CoolingIndividual
  "Cell array battery pack, with cooling of individual cells"

  extends
    .Electrification.Batteries.Experiments.Thermal.Templates.DischargeRateCoolingIndividual(
      redeclare replaceable .Electrification.Batteries.Examples.CellArray
      batteryPack(redeclare
        .Electrification.Batteries.Thermal.Examples.IndividualCells thermal(C_cell = 500 / batteryPack.ns / batteryPack.np,G_pack = 0,cellTransfer(G_cellwall = 0.5)),
        core(impedance(k_R=k_R_mod)),electrical(redeclare replaceable .Electrification.Batteries.Electrical.Array.Cells.Examples.ParallelStrings cells),limitActionV = Modelon.Types.FaultAction.Warning),
      redeclare .Modelica.Blocks.Routing.RealPassThrough filter
    );
  .Modelica.Blocks.Sources.RealExpression convectiveConductance[
    batteryPack.ns,batteryPack.np](each y=0.5)
    annotation (Placement(transformation(extent={{-80.0,58.0},{-60.0,78.0}},rotation = 0.0,origin = {0.0,0.0})));
    parameter Real anomaly_scaling(min = 0) = 10 "Scaling of resistance in malfunctioning cell" annotation(Dialog(group = "Anomaly"));
    parameter Integer anomaly_s(min = 1,max = batteryPack.ns) = 4 "Placement of malfunctioning cell, series direction" annotation(Dialog(group = "Anomaly"));
    parameter Integer anomaly_p(min = 1,max = batteryPack.np) = 2 "Placement of malfunctioning cell, parallel direction" annotation(Dialog(group = "Anomaly"));
    parameter Real k_R_mod[batteryPack.ns,batteryPack.np] = {if s == anomaly_s and p == anomaly_p then anomaly_scaling else 1 for p in 1:batteryPack.np, s in 1:batteryPack.ns} "Matrix introducing anomaly in a specific cell's internal resistance"annotation(Dialog(group = "Anomaly")); 

equation
  connect(convectiveConductance.y, convection.Gc) annotation (Line(points={{-59,68},{-28,68}}, color={0,0,127}));
annotation (Documentation(revisions="<html><!--COPYRIGHT--></html>", info="<html>
<p>This experiment is an example of applying external convective cooling to individual cells for a cell array battery pack (<a href=\"modelica://Electrification.Batteries.Examples.CellArray\">CellArray</a>).</p>
<p>The battery is being discharged at a constant rate of 1C. For more information about this experiment, please refer to the <a href=\"modelica://Electrification.Batteries.Experiments.Thermal.Templates.DischargeRateCoolingIndividual\">DischargeRateCoolingIndividual</a> experiment template.</p>
<p>Each of the individual battery cells are connected to their own separate convective cooling, via the <a href=\"modelica://Electrification.Batteries.Thermal.Adapters.Cells\">Cells</a> thermal adapter.</p>
<p>The conductance (<span style=\"font-family: Courier New;\">Gc</span>) of the convective cooling is provided as a vectorized constant input.</p>
<p>Note that thermal nodes corresponding to each cell has been enabled with the parameter batteryPack.thermal.</p>
</html>"),
      experiment(StopTime=2150, Interval=1),
    uses(Electrification(version="1.8"), Modelica(version="4.0.0")));
end CoolingIndividual;
