within SpatialPlotExamples;

model DistributedDelayPipe
  "Example with distributed pipe with transport delay function"
  extends .LiquidCooling.Experiments.Templates.ExperimentBase(redeclare package Liquid =
        .LiquidCooling.Media.Water.IncompressibleWater,visualization_option = LiquidCooling.Utilities.Choices.VisualizationOption.TemperatureVisualization);
  .LiquidCooling.Pipes.Generic.SegmentedLiquidPipe
                             pipe(
    L=1,
    n=10,
    useLumpedFriction=true,
    D=0.1,
    redeclare package Medium = Liquid,
    redeclare model Friction =
        .LiquidCooling.Pipes.SubComponents.PipeResistances.SinglePhase.DarcyWeisbach (
         zeta_A=100))
         annotation (Placement(transformation(extent={{-18,-20},{2,0}})));
  .LiquidCooling.Pipes.Generic.SegmentedLiquidPipe
                             pipe1(
    useHeatTransfer=true,
    L=1,
    n=10,
    A_heat=1,
    D=0.1,
    redeclare package Medium = Liquid,
    redeclare model HeatTransfer =
        .LiquidCooling.Pipes.SubComponents.HeatTransfer.SinglePhase.ConstantCoefficient (
         alpha=1000))
         annotation (Placement(transformation(extent={{22,-20},{42,0}})));
  .LiquidCooling.Sources.LiquidFlowSource       massFlowBoundary(
    m_flow=2,
    use_T_in=true,
    T=353.15,
    redeclare package Medium = Liquid)
              annotation (Placement(transformation(extent={{-50,-20},{-30,0}})));
  .LiquidCooling.Sources.LiquidPressureSource   pressureBoundary(
    p=300000,
    T=323.15,
    redeclare package Medium = Liquid)
              annotation (Placement(transformation(extent={{84,-20},{64,0}})));
  .Modelon.ThermoFluid.Sources.Environment_T environment_T(N=10, T0=293.15)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={32,30})));
    .Modelica.Blocks.Sources.Ramp ramp(height = 30,offset = 300,startTime = 5,duration = 30) annotation(Placement(transformation(extent = {{-80.0,10.0},{-60.0,30.0}},origin = {0.0,0.0},rotation = 0.0)));
equation
  connect(environment_T.port, pipe1.q)                 annotation (Line(
      points={{32,20},{32,-5}},
      color={191,0,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pipe.portB, pipe1.portA) annotation (Line(
      points={{2,-10},{22,-10}},
      color={0,0,255},
      smooth=Smooth.None));
  connect(massFlowBoundary.port, pipe.portA) annotation (Line(
      points={{-30,-10},{-18,-10}},
      color={0,0,255},
      smooth=Smooth.None));
  connect(pipe1.portB, pressureBoundary.port) annotation (Line(
      points={{42,-10},{64,-10}},
      color={0,0,255},
      smooth=Smooth.None));
    connect(ramp.y,massFlowBoundary.T_in) annotation(Line(points = {{-59,20},{-40,20},{-40,0}},color = {0,0,127}));
  annotation (
    Diagram(graphics),
    experiment(
      StopTime=50,
      __Dymola_NumberOfIntervals=5000,
      Tolerance=1e-006),
    Documentation(revisions="<html>
 Copyright &copy; 2004-2022, MODELON AB <br /> The use of this software component is regulated by the licensing conditions for Modelon Libraries. <br />This copyright notice must, unaltered, accompany all components that are derived from, copied from, <br />or by other means have their origin from any Modelon Library.
</html>", info="<html>
<h4>DistributedDelayPipe</h4>
<p>This is an example using distributed pipe that has alternating <i>transport delay</i> and <i>heat transfer </i>models. There is a step change in the inlet temperature at t=20s. Transport delay and heat transfer to the environment can be seen in the plot below:</p>
<p><img src=\"modelica://LiquidCooling/Resources/Images/DistributedDelayPipe.png\"/></p>
<p>More information about the pipe component can be found <a href=\"modelica://LiquidCooling.Pipes.Generic.SegmentedLiquidPipe\">here</a>.</p>
</html>"));
end DistributedDelayPipe;
